@@ -56,6 +56,9 @@ static void
 cb_zimagez_toggled                 (GtkToggleButton    *tb,
                                     ScreenshotData     *sd);
 static void
+cb_imgur_toggled                   (GtkToggleButton    *tb,
+                                    ScreenshotData     *sd);
+static void
 cb_delay_spinner_changed           (GtkWidget          *spinner,
                                     ScreenshotData     *sd);
 static gchar
@@ -190,6 +193,13 @@ static void cb_zimagez_toggled (GtkToggleButton *tb, ScreenshotData *sd)
     sd->action = UPLOAD;
 }
 
+static void cb_imgur_toggled (GtkToggleButton *tb, ScreenshotData *sd)
+{
+  if (gtk_toggle_button_get_active (tb))
+    sd->action = UPLOAD_IMGUR;
+}
+
+
 
 
 /* Set the delay according to the spinner */
@@ -203,9 +213,9 @@ static void cb_delay_spinner_changed (GtkWidget *spinner, ScreenshotData *sd)
 /* If @timestamp is true, generates a file name @title - date - hour - n.png,
  * where n is the lowest integer such as this file does not exist in the @uri
  * folder.
- * Else, generates a file name @title-n.png, where n is the lowest integer 
+ * Else, generates a file name @title-n.png, where n is the lowest integer
  * such as this file does not exist in the @uri folder.
- * 
+ *
  * @uri: uri of the folder for which the filename should be generated.
  * @title: the main title of the file name.
  * @timestamp: whether the date and the hour should be appended to the file name.
@@ -220,8 +230,9 @@ static gchar *generate_filename_for_uri (const gchar *uri,
   GFile *directory;
   GFile *file;
   gchar *base_name;
-  const gchar *date = screenshooter_get_date (TRUE);
-  const gchar *current_time = screenshooter_get_time ();
+  gchar *datetime;
+  const gchar *strftime_format = "%Y-%m-%d_%H-%M-%S";
+
   gint i;
 
   if (G_UNLIKELY (uri == NULL))
@@ -232,11 +243,12 @@ static gchar *generate_filename_for_uri (const gchar *uri,
     }
 
   TRACE ("Get the folder corresponding to the URI");
+  datetime = screenshooter_get_datetime (strftime_format);
   directory = g_file_new_for_uri (uri);
   if (!timestamp)
     base_name = g_strconcat (title, ".png", NULL);
   else
-    base_name = g_strconcat (title, " - ", date, " - ", current_time, ".png", NULL);
+    base_name = g_strconcat (title, "_", datetime, ".png", NULL);
 
   file = g_file_get_child (directory, base_name);
 
@@ -259,7 +271,7 @@ static gchar *generate_filename_for_uri (const gchar *uri,
       if (!timestamp)
          base_name = g_strconcat (title, extension, NULL);
        else
-         base_name = g_strconcat (title, " - ", date, " - ", current_time, extension, NULL);
+         base_name = g_strconcat (title, "_", datetime, extension, NULL);
 
       file = g_file_get_child (directory, base_name);
 
@@ -272,6 +284,7 @@ static gchar *generate_filename_for_uri (const gchar *uri,
       g_object_unref (file);
     }
 
+  g_free(datetime);
   g_object_unref (directory);
 
   return base_name;
@@ -311,14 +324,14 @@ static void add_item (GAppInfo *app_info, GtkWidget *liststore)
   icon_info =
     gtk_icon_theme_lookup_by_gicon (icon_theme, icon,
                                     ICON_SIZE,
-                                    GTK_ICON_LOOKUP_GENERIC_FALLBACK);
+                                    GTK_ICON_LOOKUP_FORCE_SIZE);
 
   pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
 
   if (G_UNLIKELY (pixbuf == NULL))
     {
       pixbuf = gtk_icon_theme_load_icon (icon_theme, "exec", ICON_SIZE,
-                                         GTK_ICON_LOOKUP_GENERIC_FALLBACK,
+                                         GTK_ICON_LOOKUP_FORCE_SIZE,
                                          NULL);
     }
 
@@ -334,7 +347,7 @@ static void add_item (GAppInfo *app_info, GtkWidget *liststore)
   /* Free the stuff */
   g_object_unref (pixbuf);
   g_object_unref (icon);
-  gtk_icon_info_free (icon_info);
+  g_object_unref (icon_info);
 }
 
 
@@ -510,9 +523,13 @@ static gchar
 
   if (G_UNLIKELY (!gdk_pixbuf_save (screenshot, save_path, "png", &error, NULL)))
     {
-      screenshooter_error ("%s", error->message);
+      if (error)
+        {
+          /* See bug #8443, looks like error is not set when path is NULL */
+          screenshooter_error ("%s", error->message);
+          g_error_free (error);
+        }
 
-      g_error_free (error);
       g_free (save_path);
 
       return NULL;
@@ -534,8 +551,8 @@ save_screenshot_to_remote_location (GdkPixbuf *screenshot, GFile *save_file)
 
   GtkWidget *dialog = gtk_dialog_new_with_buttons (_("Transfer"),
                                                    NULL,
-                                                   GTK_DIALOG_NO_SEPARATOR,
-                                                   GTK_STOCK_CANCEL,
+                                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                   "gtk-cancel",
                                                    GTK_RESPONSE_CANCEL,
                                                    NULL);
 
@@ -550,27 +567,28 @@ save_screenshot_to_remote_location (GdkPixbuf *screenshot, GFile *save_file)
   gtk_window_set_deletable (GTK_WINDOW (dialog), FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 20);
   gtk_window_set_icon_name (GTK_WINDOW (dialog), "document-save");
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG(dialog)->vbox), 12);
+  gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 12);
 
   gtk_label_set_markup (GTK_LABEL (label1),
                         _("<span weight=\"bold\" stretch=\"semiexpanded\">The screenshot "
                           "is being transferred to:</span>"));
-  gtk_misc_set_alignment (GTK_MISC (label1), 0, 0.5);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG(dialog)->vbox),
+  gtk_widget_set_halign (label1, GTK_ALIGN_START);
+  gtk_widget_set_valign (label1, GTK_ALIGN_CENTER);
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
                       label1,
                       FALSE,
                       FALSE,
                       0);
   gtk_widget_show (label1);
 
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG(dialog)->vbox),
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
                       label2,
                       FALSE,
                       FALSE,
                       0);
   gtk_widget_show (label2);
 
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG(dialog)->vbox),
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
                       progress_bar,
                       FALSE,
                       FALSE,
@@ -606,6 +624,12 @@ static gchar
   GFile *save_file = g_file_new_for_uri (save_uri);
   gchar *result = NULL;
 
+  if (save_uri == NULL)
+    {
+      g_object_unref (save_file);
+      return NULL;
+    }
+
   /* If the URI is a local one, we save directly */
 
   if (!screenshooter_is_remote_uri (save_uri))
@@ -653,7 +677,7 @@ GtkWidget *screenshooter_region_dialog_new (ScreenshotData *sd, gboolean plugin)
   GtkWidget *dlg, *main_alignment;
   GtkWidget *vbox;
 
-  GtkWidget *layout_table;
+  GtkWidget *layout_grid;
 
   GtkWidget *area_main_box, *area_box, *area_label, *area_alignment;
   GtkWidget *active_window_button,
@@ -671,13 +695,12 @@ GtkWidget *screenshooter_region_dialog_new (ScreenshotData *sd, gboolean plugin)
       dlg =
         xfce_titled_dialog_new_with_buttons (_("Screenshot"),
                                              NULL,
-                                             GTK_DIALOG_DESTROY_WITH_PARENT|
-                                             GTK_DIALOG_NO_SEPARATOR,
-                                             GTK_STOCK_HELP,
+                                             GTK_DIALOG_DESTROY_WITH_PARENT,
+                                             "gtk-help",
                                              GTK_RESPONSE_HELP,
-                                             GTK_STOCK_CANCEL,
+                                             "gtk-cancel",
                                              GTK_RESPONSE_CANCEL,
-                                             GTK_STOCK_OK,
+                                             "gtk-ok",
                                              GTK_RESPONSE_OK,
                                              NULL);
 
@@ -688,10 +711,10 @@ GtkWidget *screenshooter_region_dialog_new (ScreenshotData *sd, gboolean plugin)
       dlg =
         xfce_titled_dialog_new_with_buttons (_("Screenshot"),
                                              NULL,
-                                             GTK_DIALOG_DESTROY_WITH_PARENT|GTK_DIALOG_NO_SEPARATOR,
-                                             GTK_STOCK_HELP,
+                                             GTK_DIALOG_DESTROY_WITH_PARENT,
+                                             "gtk-help",
                                              GTK_RESPONSE_HELP,
-                                             GTK_STOCK_CLOSE,
+                                             "gtk-close",
                                              GTK_RESPONSE_OK,
                                              NULL);
 
@@ -706,40 +729,53 @@ GtkWidget *screenshooter_region_dialog_new (ScreenshotData *sd, gboolean plugin)
   gtk_dialog_set_default_response (GTK_DIALOG (dlg), GTK_RESPONSE_OK);
 
   /* Create the main alignment for the dialog */
-  main_alignment = gtk_alignment_new (0, 0, 1, 1);
-  gtk_alignment_set_padding (GTK_ALIGNMENT (main_alignment), 6, 0, 12, 12);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), main_alignment, TRUE, TRUE, 0);
+  main_alignment = gtk_box_new (GTK_ORIENTATION_VERTICAL, 1);
+  gtk_widget_set_hexpand (main_alignment, TRUE);
+  gtk_widget_set_vexpand (main_alignment, TRUE);
+  gtk_widget_set_margin_top (main_alignment, 6);
+  gtk_widget_set_margin_bottom (main_alignment, 0);
+  gtk_widget_set_margin_start (main_alignment, 12);
+  gtk_widget_set_margin_end (main_alignment, 12);
+
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))), main_alignment, TRUE, TRUE, 0);
 
   /* Create the main box for the dialog */
-  vbox = gtk_vbox_new (FALSE, 10);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
   gtk_container_add (GTK_CONTAINER (main_alignment), vbox);
 
-  /* Create the table to align the differents parts of the top of the UI */
-  layout_table = gtk_table_new (2, 2, FALSE);
-  gtk_table_set_col_spacings (GTK_TABLE (layout_table), 20);
-  gtk_box_pack_start (GTK_BOX (vbox), layout_table, TRUE, TRUE, 0);
+  /* Create the grid to align the differents parts of the top of the UI */
+  layout_grid = gtk_grid_new ();
+  gtk_grid_set_column_spacing (GTK_GRID (layout_grid), 20);
+  gtk_box_pack_start (GTK_BOX (vbox), layout_grid, TRUE, TRUE, 0);
 
   /* Create the main box for the regions */
-  area_main_box = gtk_vbox_new (FALSE, 6);
-  gtk_table_attach_defaults (GTK_TABLE (layout_table), area_main_box, 0, 1, 0, 2);
+  area_main_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+  gtk_grid_attach (GTK_GRID (layout_grid), area_main_box, 0, 0, 1, 2);
 
   /* Create area label */
   area_label = gtk_label_new ("");
   gtk_label_set_markup (GTK_LABEL (area_label),
                         _("<span weight=\"bold\" stretch=\"semiexpanded\">"
                           "Region to capture</span>"));
-  gtk_misc_set_alignment (GTK_MISC (area_label), 0, 0);
+  gtk_widget_set_halign (area_label, GTK_ALIGN_START);
+  gtk_widget_set_valign (area_label, GTK_ALIGN_START);
   gtk_container_add (GTK_CONTAINER (area_main_box), area_label);
 
   /* Create area alignment */
-  area_alignment = gtk_alignment_new (0, 0, 1, 1);
+  area_alignment = gtk_box_new (GTK_ORIENTATION_VERTICAL, 1);
+  gtk_widget_set_hexpand (area_alignment, TRUE);
+  gtk_widget_set_vexpand (area_alignment, TRUE);
+  gtk_widget_set_margin_top (area_alignment, 0);
+  gtk_widget_set_margin_bottom (area_alignment, 6);
+  gtk_widget_set_margin_start (area_alignment, 12);
+  gtk_widget_set_margin_end (area_alignment, 0);
   gtk_container_add (GTK_CONTAINER (area_main_box), area_alignment);
-  gtk_alignment_set_padding (GTK_ALIGNMENT (area_alignment), 0, 6, 12, 0);
 
   /* Create area box */
-  area_box = gtk_vbox_new (FALSE, 6);
+  area_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
   gtk_container_add (GTK_CONTAINER (area_alignment), area_box);
+  gtk_box_set_spacing (GTK_BOX (area_box), 12);
   gtk_container_set_border_width (GTK_CONTAINER (area_box), 0);
 
   /* Create radio buttons for areas to screenshot */
@@ -807,33 +843,40 @@ GtkWidget *screenshooter_region_dialog_new (ScreenshotData *sd, gboolean plugin)
                     G_CALLBACK (cb_toggle_set_insensi), show_mouse_checkbox);
 
   /* Create the main box for the delay stuff */
-  delay_main_box = gtk_vbox_new (FALSE, 6);
-  gtk_table_attach_defaults (GTK_TABLE (layout_table), delay_main_box, 1, 2, 0, 1);
+  delay_main_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+  gtk_grid_attach (GTK_GRID (layout_grid), delay_main_box, 1, 0, 1, 1);
 
   /* Create delay label */
   delay_label = gtk_label_new ("");
   gtk_label_set_markup (GTK_LABEL(delay_label),
                         _("<span weight=\"bold\" stretch=\"semiexpanded\">"
                           "Delay before capturing</span>"));
-  gtk_misc_set_alignment(GTK_MISC (delay_label), 0, 0);
+  gtk_widget_set_halign (delay_label, GTK_ALIGN_START);
+  gtk_widget_set_valign (delay_label, GTK_ALIGN_START);
   gtk_box_pack_start (GTK_BOX (delay_main_box), delay_label, FALSE, FALSE, 0);
 
   /* Create delay alignment */
-  delay_alignment = gtk_alignment_new (0, 0, 0, 0);
+  delay_alignment = gtk_box_new (GTK_ORIENTATION_VERTICAL, 1);
+  gtk_widget_set_hexpand (delay_alignment, FALSE);
+  gtk_widget_set_vexpand (delay_alignment, FALSE);
+  gtk_widget_set_margin_top (delay_alignment, 0);
+  gtk_widget_set_margin_bottom (delay_alignment, 6);
+  gtk_widget_set_margin_start (delay_alignment, 12);
+  gtk_widget_set_margin_end (delay_alignment, 0);
   gtk_box_pack_start (GTK_BOX (delay_main_box), delay_alignment, FALSE, FALSE, 0);
-  gtk_alignment_set_padding (GTK_ALIGNMENT (delay_alignment), 0, 6, 12, 0);
 
   /* Create delay box */
-  delay_box = gtk_vbox_new (FALSE, 0);
+  delay_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_add (GTK_CONTAINER (delay_alignment), delay_box);
   gtk_container_set_border_width (GTK_CONTAINER (delay_box), 0);
 
   /* Create delay spinner */
-  delay_spinner_box = gtk_hbox_new (FALSE, 4);
+  delay_spinner_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
   gtk_box_pack_start (GTK_BOX (delay_box), delay_spinner_box, FALSE, FALSE, 0);
 
-  delay_spinner = gtk_spin_button_new_with_range(1.0, 60.0, 1.0);
+  delay_spinner = gtk_spin_button_new_with_range(0.0, 60.0, 1.0);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (delay_spinner), sd->delay);
+  gtk_widget_set_sensitive (delay_spinner, (sd->region != SELECT));
   gtk_widget_set_tooltip_text (delay_spinner,
                                _("Delay in seconds before the screenshot is taken"));
   gtk_box_pack_start (GTK_BOX (delay_spinner_box), delay_spinner, FALSE, FALSE, 0);
@@ -842,15 +885,26 @@ GtkWidget *screenshooter_region_dialog_new (ScreenshotData *sd, gboolean plugin)
   gtk_box_pack_start (GTK_BOX (delay_spinner_box), seconds_label, FALSE, FALSE, 0);
   g_signal_connect (G_OBJECT (delay_spinner), "value-changed",
                     G_CALLBACK (cb_delay_spinner_changed), sd);
-
-  /* Set the delay box as inactive when we capture rectangles */
   g_signal_connect (G_OBJECT (rectangle_button), "toggled",
-                    G_CALLBACK (cb_toggle_set_insensi), delay_box);
+                    G_CALLBACK (cb_toggle_set_insensi), delay_spinner);
 
-  /* Set the default state */
-  cb_toggle_set_insensi (GTK_TOGGLE_BUTTON (rectangle_button), delay_box);
+  gtk_widget_show_all (gtk_dialog_get_content_area (GTK_DIALOG (dlg)));
 
-  gtk_widget_show_all (GTK_DIALOG (dlg)->vbox);
+  /* Set focus to the selected radio button */
+  switch (sd->region)
+    {
+      case FULLSCREEN:
+        gtk_widget_grab_focus (fullscreen_button);
+        break;
+      case ACTIVE_WINDOW:
+        gtk_widget_grab_focus (active_window_button);
+        break;
+      case SELECT:
+        gtk_widget_grab_focus (rectangle_button);
+        break;
+      default:
+        break;
+    }
 
   return dlg;
 }
@@ -863,16 +917,17 @@ GtkWidget *screenshooter_actions_dialog_new (ScreenshotData *sd)
   GtkWidget *dlg, *main_alignment;
   GtkWidget *vbox;
 
-  GtkWidget *layout_table;
+  GtkWidget *layout_grid;
 
   GtkWidget *left_box;
-  GtkWidget *actions_label, *actions_alignment, *actions_box;
+  GtkWidget *actions_label, *actions_alignment, *actions_grid;
   GtkWidget *save_radio_button;
   GtkWidget *clipboard_radio_button, *open_with_radio_button;
   GtkWidget *zimagez_radio_button;
+  GtkWidget *imgur_radio_button;
 
   GtkListStore *liststore;
-  GtkWidget *combobox, *open_box;
+  GtkWidget *combobox;
   GtkCellRenderer *renderer, *renderer_pixbuf;
 
   GtkWidget *preview, *preview_ebox, *preview_box, *preview_label;
@@ -880,13 +935,12 @@ GtkWidget *screenshooter_actions_dialog_new (ScreenshotData *sd)
 
   dlg = xfce_titled_dialog_new_with_buttons (_("Screenshot"),
                                              NULL,
-                                             GTK_DIALOG_DESTROY_WITH_PARENT|
-                                             GTK_DIALOG_NO_SEPARATOR,
-                                             GTK_STOCK_HELP,
+                                             GTK_DIALOG_DESTROY_WITH_PARENT,
+                                             "gtk-help",
                                              GTK_RESPONSE_HELP,
-                                             GTK_STOCK_CANCEL,
+                                             "gtk-cancel",
                                              GTK_RESPONSE_CANCEL,
-                                             GTK_STOCK_OK,
+                                             "gtk-ok",
                                              GTK_RESPONSE_OK,
                                              NULL);
 
@@ -898,41 +952,55 @@ GtkWidget *screenshooter_actions_dialog_new (ScreenshotData *sd)
   gtk_dialog_set_default_response (GTK_DIALOG (dlg), GTK_RESPONSE_OK);
 
   /* Create the main alignment for the dialog */
-  main_alignment = gtk_alignment_new (0, 0, 1, 1);
-  gtk_alignment_set_padding (GTK_ALIGNMENT (main_alignment), 6, 0, 12, 12);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), main_alignment, TRUE, TRUE, 0);
+  main_alignment = gtk_box_new (GTK_ORIENTATION_VERTICAL, 1);
+  gtk_widget_set_hexpand (main_alignment, TRUE);
+  gtk_widget_set_vexpand (main_alignment, TRUE);
+  gtk_widget_set_margin_top (main_alignment, 6);
+  gtk_widget_set_margin_bottom (main_alignment, 0);
+  gtk_widget_set_margin_start (main_alignment, 12);
+  gtk_widget_set_margin_end (main_alignment, 12);
+  gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))), main_alignment, TRUE, TRUE, 0);
 
   /* Create the main box for the dialog */
-  vbox = gtk_vbox_new (FALSE, 10);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
   gtk_container_add (GTK_CONTAINER (main_alignment), vbox);
 
-  /* Create the table to align the two columns of the UI */
-  layout_table = gtk_table_new (1, 2, FALSE);
-  gtk_table_set_col_spacings (GTK_TABLE (layout_table), 30);
-  gtk_box_pack_start (GTK_BOX (vbox), layout_table, TRUE, TRUE, 0);
+  /* Create the grid to align the two columns of the UI */
+  layout_grid = gtk_grid_new ();
+  gtk_grid_set_column_spacing (GTK_GRID (layout_grid), 20);
+  gtk_box_pack_start (GTK_BOX (vbox), layout_grid, TRUE, TRUE, 0);
 
   /* Create the box which containes the left part of the UI */
-  left_box = gtk_vbox_new (FALSE, 6);
-  gtk_table_attach_defaults (GTK_TABLE (layout_table), left_box, 0, 1, 0, 1);
+  left_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+  gtk_grid_attach (GTK_GRID (layout_grid), left_box, 0, 0, 1, 1);
 
   /* Create actions label */
   actions_label = gtk_label_new ("");
   gtk_label_set_markup (GTK_LABEL (actions_label),
                         _("<span weight=\"bold\" stretch=\"semiexpanded\">Action"
                           "</span>"));
-  gtk_misc_set_alignment (GTK_MISC (actions_label), 0, 0);
+  gtk_widget_set_halign (actions_label, GTK_ALIGN_START);
+  gtk_widget_set_valign (actions_label, GTK_ALIGN_START);
   gtk_box_pack_start (GTK_BOX (left_box), actions_label, FALSE, FALSE, 0);
 
   /* Create actions alignment */
-  actions_alignment = gtk_alignment_new (0, 0, 1, 1);
-  gtk_alignment_set_padding (GTK_ALIGNMENT (actions_alignment), 0, 6, 12, 0);
+  actions_alignment = gtk_box_new (GTK_ORIENTATION_VERTICAL, 1);
+  gtk_widget_set_hexpand (actions_alignment, TRUE);
+  gtk_widget_set_vexpand (actions_alignment, TRUE);
+  gtk_widget_set_margin_top (actions_alignment, 0);
+  gtk_widget_set_margin_bottom (actions_alignment, 6);
+  gtk_widget_set_margin_start (actions_alignment, 12);
+  gtk_widget_set_margin_end (actions_alignment, 0);
   gtk_box_pack_start (GTK_BOX (left_box), actions_alignment, TRUE, TRUE, 0);
 
   /* Create the actions box */
-  actions_box = gtk_vbox_new (FALSE, 6);
-  gtk_container_add (GTK_CONTAINER (actions_alignment), actions_box);
-  gtk_container_set_border_width (GTK_CONTAINER (actions_box), 0);
+  actions_grid = gtk_grid_new ();
+  gtk_container_add (GTK_CONTAINER (actions_alignment), actions_grid);
+
+  gtk_grid_set_row_spacing (GTK_GRID (actions_grid), 6);
+  gtk_grid_set_column_spacing (GTK_GRID (actions_grid), 6);
+  gtk_container_set_border_width (GTK_CONTAINER (actions_grid), 0);
 
   /* Save option radio button */
   save_radio_button = gtk_radio_button_new_with_mnemonic (NULL, _("Save"));
@@ -941,7 +1009,7 @@ GtkWidget *screenshooter_actions_dialog_new (ScreenshotData *sd)
   g_signal_connect (G_OBJECT (save_radio_button), "toggled",
                     G_CALLBACK (cb_save_toggled), sd);
   gtk_widget_set_tooltip_text (save_radio_button, _("Save the screenshot to a PNG file"));
-  gtk_box_pack_start (GTK_BOX (actions_box), save_radio_button, FALSE, FALSE, 0);
+  gtk_grid_attach (GTK_GRID (actions_grid), save_radio_button, 0, 0, 1, 1);
 
   if (sd->plugin ||
       gdk_display_supports_clipboard_persistence (gdk_display_get_default ()))
@@ -957,14 +1025,9 @@ GtkWidget *screenshooter_actions_dialog_new (ScreenshotData *sd)
                                     (sd->action == CLIPBOARD));
       g_signal_connect (G_OBJECT (clipboard_radio_button), "toggled",
                         G_CALLBACK (cb_clipboard_toggled), sd);
-      gtk_box_pack_start (GTK_BOX (actions_box), clipboard_radio_button, FALSE, FALSE, 0);
+      gtk_grid_attach (GTK_GRID (actions_grid), clipboard_radio_button, 0, 1, 1, 1);
     }
 
-  /* Horizontal box for the open with stuff */
-  open_box = gtk_hbox_new (FALSE, 6);
-  gtk_container_set_border_width (GTK_CONTAINER (open_box), 0);
-  gtk_box_pack_start (GTK_BOX (actions_box), open_box, FALSE, FALSE, 0);
-
   /* Open with radio button */
   open_with_radio_button =
     gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (save_radio_button),
@@ -975,7 +1038,7 @@ GtkWidget *screenshooter_actions_dialog_new (ScreenshotData *sd)
                     G_CALLBACK (cb_open_toggled), sd);
   gtk_widget_set_tooltip_text (open_with_radio_button,
                                _("Open the screenshot with the chosen application"));
-  gtk_box_pack_start (GTK_BOX (open_box), open_with_radio_button, FALSE, FALSE, 0);
+  gtk_grid_attach (GTK_GRID (actions_grid), open_with_radio_button, 0, 2, 1, 1);
 
   /* Open with combobox */
   liststore = gtk_list_store_new (3, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_STRING);
@@ -989,7 +1052,8 @@ GtkWidget *screenshooter_actions_dialog_new (ScreenshotData *sd)
                                   "pixbuf", 0, NULL);
   populate_liststore (liststore);
   set_default_item (combobox, sd);
-  gtk_box_pack_start (GTK_BOX (open_box), combobox, TRUE, TRUE, 0);
+  gtk_grid_attach (GTK_GRID (actions_grid), combobox, 1, 2, 1, 1);
+
   g_signal_connect (G_OBJECT (combobox), "changed",
                     G_CALLBACK (cb_combo_active_item_changed), sd);
   gtk_widget_set_tooltip_text (combobox, _("Application to open the screenshot"));
@@ -1010,19 +1074,33 @@ GtkWidget *screenshooter_actions_dialog_new (ScreenshotData *sd)
                                  "image hosting service"));
   g_signal_connect (G_OBJECT (zimagez_radio_button), "toggled",
                     G_CALLBACK (cb_zimagez_toggled), sd);
-  gtk_box_pack_start (GTK_BOX (actions_box), zimagez_radio_button, FALSE, FALSE, 0);
+  gtk_grid_attach (GTK_GRID (actions_grid), zimagez_radio_button, 0, 3, 1, 1);
+
+  /* Upload to imgur radio button */
+  imgur_radio_button =
+    gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (save_radio_button),
+                                                 _("Host on Imgur"));
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (imgur_radio_button),
+                                (sd->action == UPLOAD_IMGUR));
+  gtk_widget_set_tooltip_text (imgur_radio_button,
+                               _("Host the screenshot on Imgur, a free online "
+                                 "image hosting service"));
+  g_signal_connect (G_OBJECT (imgur_radio_button), "toggled",
+                    G_CALLBACK (cb_imgur_toggled), sd);
+  gtk_grid_attach (GTK_GRID (actions_grid), imgur_radio_button, 0, 4, 1, 1);
 
   /* Preview box */
-  preview_box = gtk_vbox_new (FALSE, 6);
+  preview_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
   gtk_container_set_border_width (GTK_CONTAINER (preview_box), 0);
-  gtk_table_attach_defaults (GTK_TABLE (layout_table), preview_box, 1, 2, 0, 1);
+  gtk_grid_attach (GTK_GRID (layout_grid), preview_box, 1, 0, 1, 1);
 
   /* Preview label*/
   preview_label = gtk_label_new ("");
   gtk_label_set_markup (GTK_LABEL (preview_label),
                         _("<span weight=\"bold\" stretch=\"semiexpanded\">"
                           "Preview</span>"));
-  gtk_misc_set_alignment (GTK_MISC (preview_label), 0, 0.5);
+  gtk_widget_set_halign (preview_label, GTK_ALIGN_START);
+  gtk_widget_set_valign (preview_label, GTK_ALIGN_CENTER);
   gtk_box_pack_start (GTK_BOX (preview_box), preview_label, FALSE, FALSE, 0);
 
   /* The preview image */
@@ -1040,7 +1118,7 @@ GtkWidget *screenshooter_actions_dialog_new (ScreenshotData *sd)
   g_signal_connect (preview_ebox, "drag-data-get", G_CALLBACK (preview_drag_data_get), sd->screenshot);
   g_signal_connect (preview_ebox, "drag-end", G_CALLBACK (preview_drag_end), dlg);
 
-  gtk_widget_show_all (GTK_DIALOG (dlg)->vbox);
+  gtk_widget_show_all (gtk_dialog_get_content_area (GTK_DIALOG (dlg)));
 
   return dlg;
 }
@@ -1084,9 +1162,9 @@ gchar
       gtk_file_chooser_dialog_new (_("Save screenshot as..."),
                                    NULL,
                                    GTK_FILE_CHOOSER_ACTION_SAVE,
-                                   GTK_STOCK_CANCEL,
+                                   "gtk-cancel",
                                    GTK_RESPONSE_CANCEL,
-                                   GTK_STOCK_SAVE,
+                                   "gtk-save",
                                    GTK_RESPONSE_ACCEPT,
                                    NULL);
 
